@@ -41,7 +41,7 @@ kFoldCrossValidation <- function(object,
         ## fit.k$call <- NULL
         ## however, it does not work with the new version of the survival package
         ## in which the survfit.coxph function checks the response 'y'
-        fit.k$call$data <- substitute(train.k)
+        ## fit.k$call$data <- substitute(train.k)
         fit.k
       })
       # }}}
@@ -50,24 +50,13 @@ kFoldCrossValidation <- function(object,
         fit.k <- trainModels[[f]]
         extraArgs <- giveToModel[[f]]
         if (predictHandlerFun == "predictEventProb"){      
-          p.group <- do.call(predictHandlerFun,
-                             c(list(object=fit.k,
-                                    newdata=val.k,
-                                    times=times,
-                                    cause=cause,
-                                    train.data=train.k),
-                               extraArgs))
+          p.group <- do.call(predictHandlerFun,c(list(object=fit.k,newdata=val.k,times=times,cause=cause,train.data=train.k),extraArgs))
         }
         else{
-          p.group <- do.call(predictHandlerFun,c(list(object=fit.k,
-                                                      newdata=val.k,
-                                                      times=times,
-                                                      train.data=train.k),extraArgs))
+          p.group <- do.call(predictHandlerFun,c(list(object=fit.k,newdata=val.k,times=times,train.data=train.k),extraArgs))
         }
         if(is.null(dim(p.group))) {
-          p.group <- do.call("rbind",
-                             lapply(1:NROW(val.k),
-                                    function(x){p.group}))
+          p.group <- do.call("rbind",lapply(1:NROW(val.k),function(x){p.group}))
         }
         p.group
       })
